Class: Google::Apis::CloudbuildV2::CreateRepositoryRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Message for creating a Repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateRepositoryRequest

Returns a new instance of CreateRepositoryRequest.



513
514
515
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The connection to contain the repository. If the request is part of a BatchCreateRepositoriesRequest, this field should be empty or match the parent specified there. Corresponds to the JSON property parent

Returns:

  • (String)


499
500
501
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 499

def parent
  @parent
end

#repositoryGoogle::Apis::CloudbuildV2::Repository

A repository associated to a parent connection. Corresponds to the JSON property repository



504
505
506
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 504

def repository
  @repository
end

#repository_idString

Required. The ID to use for the repository, which will become the final component of the repository's resource name. This ID should be unique in the connection. Allows alphanumeric characters and any of -._~%!$&'()*+,;=@. Corresponds to the JSON property repositoryId

Returns:

  • (String)


511
512
513
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 511

def repository_id
  @repository_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



518
519
520
521
522
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 518

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @repository = args[:repository] if args.key?(:repository)
  @repository_id = args[:repository_id] if args.key?(:repository_id)
end