Class: Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2Condition

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Conditions defines a readiness condition for a Knative resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV2Condition

Returns a new instance of GoogleDevtoolsCloudbuildV2Condition.



869
870
871
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

LastTransitionTime is the last time the condition transitioned from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


842
843
844
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 842

def last_transition_time
  @last_transition_time
end

#messageString

A human readable message indicating details about the transition. Corresponds to the JSON property message

Returns:

  • (String)


847
848
849
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 847

def message
  @message
end

#reasonString

The reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


852
853
854
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 852

def reason
  @reason
end

#severityString

Severity with which to treat failures of this type of condition. Corresponds to the JSON property severity

Returns:

  • (String)


857
858
859
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 857

def severity
  @severity
end

#statusString

Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


862
863
864
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 862

def status
  @status
end

#typeString

Type of condition. Corresponds to the JSON property type

Returns:

  • (String)


867
868
869
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 867

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



874
875
876
877
878
879
880
881
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 874

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @severity = args[:severity] if args.key?(:severity)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end