Class: Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
Configuration for connections to an instance of GitHub Enterprise.
Instance Attribute Summary collapse
-
#api_key ⇒ String
Required.
-
#app_id ⇒ Fixnum
Optional.
-
#app_installation_id ⇒ Fixnum
Optional.
-
#app_slug ⇒ String
Optional.
-
#host_uri ⇒ String
Required.
-
#private_key_secret_version ⇒ String
Optional.
-
#server_version ⇒ String
Output only.
-
#service_directory_config ⇒ Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a connection.
-
#ssl_ca ⇒ String
Optional.
-
#webhook_secret_secret_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig
constructor
A new instance of GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig
Returns a new instance of GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig.
941 942 943 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key ⇒ String
Required. API Key used for authentication of webhook events.
Corresponds to the JSON property apiKey
891 892 893 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 891 def api_key @api_key end |
#app_id ⇒ Fixnum
Optional. Id of the GitHub App created from the manifest.
Corresponds to the JSON property appId
896 897 898 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 896 def app_id @app_id end |
#app_installation_id ⇒ Fixnum
Optional. ID of the installation of the GitHub App.
Corresponds to the JSON property appInstallationId
901 902 903 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 901 def app_installation_id @app_installation_id end |
#app_slug ⇒ String
Optional. The URL-friendly name of the GitHub App.
Corresponds to the JSON property appSlug
906 907 908 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 906 def app_slug @app_slug end |
#host_uri ⇒ String
Required. The URI of the GitHub Enterprise host this connection is for.
Corresponds to the JSON property hostUri
911 912 913 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 911 def host_uri @host_uri end |
#private_key_secret_version ⇒ String
Optional. SecretManager resource containing the private key of the GitHub App,
formatted as projects/*/secrets/*/versions/*.
Corresponds to the JSON property privateKeySecretVersion
917 918 919 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 917 def private_key_secret_version @private_key_secret_version end |
#server_version ⇒ String
Output only. GitHub Enterprise version installed at the host_uri.
Corresponds to the JSON property serverVersion
922 923 924 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 922 def server_version @server_version end |
#service_directory_config ⇒ Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2ServiceDirectoryConfig
ServiceDirectoryConfig represents Service Directory configuration for a
connection.
Corresponds to the JSON property serviceDirectoryConfig
928 929 930 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 928 def service_directory_config @service_directory_config end |
#ssl_ca ⇒ String
Optional. SSL certificate to use for requests to GitHub Enterprise.
Corresponds to the JSON property sslCa
933 934 935 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 933 def ssl_ca @ssl_ca end |
#webhook_secret_secret_version ⇒ String
Optional. SecretManager resource containing the webhook secret of the GitHub
App, formatted as projects/*/secrets/*/versions/*.
Corresponds to the JSON property webhookSecretSecretVersion
939 940 941 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 939 def webhook_secret_secret_version @webhook_secret_secret_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
946 947 948 949 950 951 952 953 954 955 956 957 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 946 def update!(**args) @api_key = args[:api_key] if args.key?(:api_key) @app_id = args[:app_id] if args.key?(:app_id) @app_installation_id = args[:app_installation_id] if args.key?(:app_installation_id) @app_slug = args[:app_slug] if args.key?(:app_slug) @host_uri = args[:host_uri] if args.key?(:host_uri) @private_key_secret_version = args[:private_key_secret_version] if args.key?(:private_key_secret_version) @server_version = args[:server_version] if args.key?(:server_version) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) @ssl_ca = args[:ssl_ca] if args.key?(:ssl_ca) @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version) end |