Class: Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitLabConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Configuration for connections to gitlab.com or an instance of GitLab Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV2GitLabConfig

Returns a new instance of GoogleDevtoolsCloudbuildV2GitLabConfig.



1005
1006
1007
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizer_credentialGoogle::Apis::CloudbuildV2::UserCredential

Represents a personal access token that authorized the Connection, and associated metadata. Corresponds to the JSON property authorizerCredential



969
970
971
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 969

def authorizer_credential
  @authorizer_credential
end

#host_uriString

Optional. The URI of the GitLab Enterprise host this connection is for. If not specified, the default value is https://gitlab.com. Corresponds to the JSON property hostUri

Returns:

  • (String)


975
976
977
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 975

def host_uri
  @host_uri
end

#read_authorizer_credentialGoogle::Apis::CloudbuildV2::UserCredential

Represents a personal access token that authorized the Connection, and associated metadata. Corresponds to the JSON property readAuthorizerCredential



981
982
983
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 981

def read_authorizer_credential
  @read_authorizer_credential
end

#server_versionString

Output only. Version of the GitLab Enterprise server running on the host_uri. Corresponds to the JSON property serverVersion

Returns:

  • (String)


986
987
988
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 986

def server_version
  @server_version
end

#service_directory_configGoogle::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2ServiceDirectoryConfig

ServiceDirectoryConfig represents Service Directory configuration for a connection. Corresponds to the JSON property serviceDirectoryConfig



992
993
994
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 992

def service_directory_config
  @service_directory_config
end

#ssl_caString

Optional. SSL certificate to use for requests to GitLab Enterprise. Corresponds to the JSON property sslCa

Returns:

  • (String)


997
998
999
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 997

def ssl_ca
  @ssl_ca
end

#webhook_secret_secret_versionString

Required. Immutable. SecretManager resource containing the webhook secret of a GitLab Enterprise project, formatted as projects/*/secrets/*/versions/*. Corresponds to the JSON property webhookSecretSecretVersion

Returns:

  • (String)


1003
1004
1005
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1003

def webhook_secret_secret_version
  @webhook_secret_secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1010
1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1010

def update!(**args)
  @authorizer_credential = args[:authorizer_credential] if args.key?(:authorizer_credential)
  @host_uri = args[:host_uri] if args.key?(:host_uri)
  @read_authorizer_credential = args[:read_authorizer_credential] if args.key?(:read_authorizer_credential)
  @server_version = args[:server_version] if args.key?(:server_version)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @ssl_ca = args[:ssl_ca] if args.key?(:ssl_ca)
  @webhook_secret_secret_version = args[:webhook_secret_secret_version] if args.key?(:webhook_secret_secret_version)
end