Class: Google::Apis::CloudbuildV2::InstallationState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Describes stage and necessary actions to be taken by the user to complete the installation. Used for GitHub and GitHub Enterprise based connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstallationState

Returns a new instance of InstallationState.



1171
1172
1173
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_uriString

Output only. Link to follow for next action. Empty string if the installation is already complete. Corresponds to the JSON property actionUri

Returns:

  • (String)


1158
1159
1160
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1158

def action_uri
  @action_uri
end

#messageString

Output only. Message of what the user should do next to continue the installation. Empty string if the installation is already complete. Corresponds to the JSON property message

Returns:

  • (String)


1164
1165
1166
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1164

def message
  @message
end

#stageString

Output only. Current step of the installation process. Corresponds to the JSON property stage

Returns:

  • (String)


1169
1170
1171
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1169

def stage
  @stage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1176
1177
1178
1179
1180
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1176

def update!(**args)
  @action_uri = args[:action_uri] if args.key?(:action_uri)
  @message = args[:message] if args.key?(:message)
  @stage = args[:stage] if args.key?(:stage)
end