Class: Google::Apis::CloudbuildV2::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1449
1450
1451
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1413

def api_version
  @api_version
end

#cancel_requestedBoolean Also known as: cancel_requested?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelRequested

Returns:

  • (Boolean)


1421
1422
1423
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1421

def cancel_requested
  @cancel_requested
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1427

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1432

def end_time
  @end_time
end

#status_detailString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusDetail

Returns:

  • (String)


1437
1438
1439
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1437

def status_detail
  @status_detail
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1442
1443
1444
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1442

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1447

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1454
1455
1456
1457
1458
1459
1460
1461
1462
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1454

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end