Class: Google::Apis::CloudbuildV2::PipelineRef
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::PipelineRef
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
PipelineRef can be used to refer to a specific instance of a Pipeline.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#params ⇒ Array<Google::Apis::CloudbuildV2::Param>
Params contains the parameters used to identify the referenced Tekton resource.
-
#resolver ⇒ String
Resolver is the name of the resolver that should perform resolution of the referenced Tekton resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PipelineRef
constructor
A new instance of PipelineRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PipelineRef
Returns a new instance of PipelineRef.
1588 1589 1590 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. Name of the Pipeline.
Corresponds to the JSON property name
1573 1574 1575 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1573 def name @name end |
#params ⇒ Array<Google::Apis::CloudbuildV2::Param>
Params contains the parameters used to identify the referenced Tekton resource.
Example entries might include "repo" or "path" but the set of params
ultimately depends on the chosen resolver.
Corresponds to the JSON property params
1580 1581 1582 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1580 def params @params end |
#resolver ⇒ String
Resolver is the name of the resolver that should perform resolution of the
referenced Tekton resource.
Corresponds to the JSON property resolver
1586 1587 1588 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1586 def resolver @resolver end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1593 1594 1595 1596 1597 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1593 def update!(**args) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @resolver = args[:resolver] if args.key?(:resolver) end |