Class: Google::Apis::CloudbuildV2::PipelineRun

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Message describing PipelineRun object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineRun

Returns a new instance of PipelineRun.



1796
1797
1798
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

User annotations. See https://google.aip.dev/128#annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1644
1645
1646
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1644

def annotations
  @annotations
end

#child_referencesArray<Google::Apis::CloudbuildV2::ChildStatusReference>

Output only. List of TaskRun and Run names and PipelineTask names for children of this PipelineRun. Corresponds to the JSON property childReferences



1650
1651
1652
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1650

def child_references
  @child_references
end

#completion_timeString

Output only. Time the pipeline completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


1655
1656
1657
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1655

def completion_time
  @completion_time
end

#conditionsArray<Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2Condition>

Output only. Kubernetes Conditions convention for PipelineRun status and error. Corresponds to the JSON property conditions



1660
1661
1662
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1660

def conditions
  @conditions
end

#create_timeString

Output only. Time at which the request to create the PipelineRun was received. Corresponds to the JSON property createTime

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1666

def create_time
  @create_time
end

#etagString

Needed for declarative-friendly resources. Corresponds to the JSON property etag

Returns:

  • (String)


1671
1672
1673
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1671

def etag
  @etag
end

#finally_start_timeString

Output only. FinallyStartTime is when all non-finally tasks have been completed and only finally tasks are being executed. +optional Corresponds to the JSON property finallyStartTime

Returns:

  • (String)


1677
1678
1679
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1677

def finally_start_time
  @finally_start_time
end

#gcb_paramsHash<String,String>

Output only. GCB default params. Corresponds to the JSON property gcbParams

Returns:

  • (Hash<String,String>)


1682
1683
1684
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1682

def gcb_params
  @gcb_params
end

#nameString

Output only. The PipelineRun name with format projects/project/locations/ location/pipelineRuns/pipeline_run` Corresponds to the JSON propertyname`

Returns:

  • (String)


1688
1689
1690
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1688

def name
  @name
end

#paramsArray<Google::Apis::CloudbuildV2::Param>

Params is a list of parameter names and values. Corresponds to the JSON property params



1693
1694
1695
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1693

def params
  @params
end

#pipeline_refGoogle::Apis::CloudbuildV2::PipelineRef

PipelineRef can be used to refer to a specific instance of a Pipeline. Corresponds to the JSON property pipelineRef



1698
1699
1700
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1698

def pipeline_ref
  @pipeline_ref
end

#pipeline_run_statusString

Pipelinerun status the user can provide. Used for cancellation. Corresponds to the JSON property pipelineRunStatus

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1703

def pipeline_run_status
  @pipeline_run_status
end

#pipeline_specGoogle::Apis::CloudbuildV2::PipelineSpec

PipelineSpec defines the desired state of Pipeline. Corresponds to the JSON property pipelineSpec



1708
1709
1710
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1708

def pipeline_spec
  @pipeline_spec
end

#pipeline_spec_yamlString

Output only. Inline pipelineSpec yaml string, used by workflow run requests. Corresponds to the JSON property pipelineSpecYaml

Returns:

  • (String)


1713
1714
1715
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1713

def pipeline_spec_yaml
  @pipeline_spec_yaml
end

#provenanceGoogle::Apis::CloudbuildV2::Provenance

Provenance configuration. Corresponds to the JSON property provenance



1718
1719
1720
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1718

def provenance
  @provenance
end

#recordString

Output only. The Record of this PipelineRun. Format: projects/project/ locations/location/results/result_id/records/record_id` Corresponds to the JSON propertyrecord`

Returns:

  • (String)


1724
1725
1726
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1724

def record
  @record
end

#resolved_pipeline_specGoogle::Apis::CloudbuildV2::PipelineSpec

PipelineSpec defines the desired state of Pipeline. Corresponds to the JSON property resolvedPipelineSpec



1729
1730
1731
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1729

def resolved_pipeline_spec
  @resolved_pipeline_spec
end

#resultsArray<Google::Apis::CloudbuildV2::PipelineRunResult>

Optional. Output only. List of results written out by the pipeline's containers Corresponds to the JSON property results



1735
1736
1737
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1735

def results
  @results
end

#securityGoogle::Apis::CloudbuildV2::Security

Security configuration. Corresponds to the JSON property security



1740
1741
1742
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1740

def security
  @security
end

#service_accountString

Service account used in the Pipeline. Deprecated; please use security. service_account instead. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1746
1747
1748
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1746

def 
  @service_account
end

#skipped_tasksArray<Google::Apis::CloudbuildV2::SkippedTask>

Output only. List of tasks that were skipped due to when expressions evaluating to false. Corresponds to the JSON property skippedTasks



1752
1753
1754
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1752

def skipped_tasks
  @skipped_tasks
end

#start_timeString

Output only. Time the pipeline is actually started. Corresponds to the JSON property startTime

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1757

def start_time
  @start_time
end

#timeoutsGoogle::Apis::CloudbuildV2::TimeoutFields

TimeoutFields allows granular specification of pipeline, task, and finally timeouts Corresponds to the JSON property timeouts



1763
1764
1765
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1763

def timeouts
  @timeouts
end

#uidString

Output only. A unique identifier for the PipelineRun. Corresponds to the JSON property uid

Returns:

  • (String)


1768
1769
1770
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1768

def uid
  @uid
end

#update_timeString

Output only. Time at which the request to update the PipelineRun was received. Corresponds to the JSON property updateTime

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1774

def update_time
  @update_time
end

#workerGoogle::Apis::CloudbuildV2::Worker

Configuration for the worker. Corresponds to the JSON property worker



1779
1780
1781
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1779

def worker
  @worker
end

#worker_poolString

Output only. The WorkerPool used to run this PipelineRun. Corresponds to the JSON property workerPool

Returns:

  • (String)


1784
1785
1786
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1784

def worker_pool
  @worker_pool
end

#workflowString

Output only. The Workflow used to create this PipelineRun. Corresponds to the JSON property workflow

Returns:

  • (String)


1789
1790
1791
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1789

def workflow
  @workflow
end

#workspacesArray<Google::Apis::CloudbuildV2::WorkspaceBinding>

Workspaces is a list of WorkspaceBindings from volumes to workspaces. Corresponds to the JSON property workspaces



1794
1795
1796
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1794

def workspaces
  @workspaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1801

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @child_references = args[:child_references] if args.key?(:child_references)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @finally_start_time = args[:finally_start_time] if args.key?(:finally_start_time)
  @gcb_params = args[:gcb_params] if args.key?(:gcb_params)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @pipeline_ref = args[:pipeline_ref] if args.key?(:pipeline_ref)
  @pipeline_run_status = args[:pipeline_run_status] if args.key?(:pipeline_run_status)
  @pipeline_spec = args[:pipeline_spec] if args.key?(:pipeline_spec)
  @pipeline_spec_yaml = args[:pipeline_spec_yaml] if args.key?(:pipeline_spec_yaml)
  @provenance = args[:provenance] if args.key?(:provenance)
  @record = args[:record] if args.key?(:record)
  @resolved_pipeline_spec = args[:resolved_pipeline_spec] if args.key?(:resolved_pipeline_spec)
  @results = args[:results] if args.key?(:results)
  @security = args[:security] if args.key?(:security)
  @service_account = args[:service_account] if args.key?(:service_account)
  @skipped_tasks = args[:skipped_tasks] if args.key?(:skipped_tasks)
  @start_time = args[:start_time] if args.key?(:start_time)
  @timeouts = args[:timeouts] if args.key?(:timeouts)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @worker = args[:worker] if args.key?(:worker)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
  @workflow = args[:workflow] if args.key?(:workflow)
  @workspaces = args[:workspaces] if args.key?(:workspaces)
end