Class: Google::Apis::CloudbuildV2::PipelineSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

PipelineSpec defines the desired state of Pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineSpec

Returns a new instance of PipelineSpec.



1898
1899
1900
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#finally_tasksArray<Google::Apis::CloudbuildV2::PipelineTask>

List of Tasks that execute just before leaving the Pipeline i.e. either after all Tasks are finished executing successfully or after a failure which would result in ending the Pipeline. Corresponds to the JSON property finallyTasks



1868
1869
1870
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1868

def finally_tasks
  @finally_tasks
end

#generated_yamlString

Output only. auto-generated yaml that is output only for display purpose for workflows using pipeline_spec, used by UI/gcloud cli for Workflows. Corresponds to the JSON property generatedYaml

Returns:

  • (String)


1874
1875
1876
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1874

def generated_yaml
  @generated_yaml
end

#paramsArray<Google::Apis::CloudbuildV2::ParamSpec>

List of parameters. Corresponds to the JSON property params



1879
1880
1881
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1879

def params
  @params
end

#resultsArray<Google::Apis::CloudbuildV2::PipelineResult>

Optional. Output only. List of results written out by the pipeline's containers Corresponds to the JSON property results



1885
1886
1887
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1885

def results
  @results
end

#tasksArray<Google::Apis::CloudbuildV2::PipelineTask>

List of Tasks that execute when this Pipeline is run. Corresponds to the JSON property tasks



1890
1891
1892
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1890

def tasks
  @tasks
end

#workspacesArray<Google::Apis::CloudbuildV2::PipelineWorkspaceDeclaration>

Workspaces declares a set of named workspaces that are expected to be provided by a PipelineRun. Corresponds to the JSON property workspaces



1896
1897
1898
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1896

def workspaces
  @workspaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1903

def update!(**args)
  @finally_tasks = args[:finally_tasks] if args.key?(:finally_tasks)
  @generated_yaml = args[:generated_yaml] if args.key?(:generated_yaml)
  @params = args[:params] if args.key?(:params)
  @results = args[:results] if args.key?(:results)
  @tasks = args[:tasks] if args.key?(:tasks)
  @workspaces = args[:workspaces] if args.key?(:workspaces)
end