Class: Google::Apis::CloudbuildV2::PipelineTask

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

PipelineTask defines a task in a Pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineTask

Returns a new instance of PipelineTask.



1967
1968
1969
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the task. Corresponds to the JSON property name

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1920

def name
  @name
end

#paramsArray<Google::Apis::CloudbuildV2::Param>

Params is a list of parameter names and values. Corresponds to the JSON property params



1925
1926
1927
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1925

def params
  @params
end

#retriesFixnum

Retries represents how many times this task should be retried in case of task failure. Corresponds to the JSON property retries

Returns:

  • (Fixnum)


1931
1932
1933
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1931

def retries
  @retries
end

#run_afterArray<String>

RunAfter is the list of PipelineTask names that should be executed before this Task executes. (Used to force a specific ordering in graph execution.) Corresponds to the JSON property runAfter

Returns:

  • (Array<String>)


1937
1938
1939
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1937

def run_after
  @run_after
end

#task_refGoogle::Apis::CloudbuildV2::TaskRef

TaskRef can be used to refer to a specific instance of a task. PipelineRef can be used to refer to a specific instance of a Pipeline. Corresponds to the JSON property taskRef



1943
1944
1945
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1943

def task_ref
  @task_ref
end

#task_specGoogle::Apis::CloudbuildV2::EmbeddedTask

EmbeddedTask defines a Task that is embedded in a Pipeline. Corresponds to the JSON property taskSpec



1948
1949
1950
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1948

def task_spec
  @task_spec
end

#timeoutString

Time after which the TaskRun times out. Defaults to 1 hour. Specified TaskRun timeout should be less than 24h. Corresponds to the JSON property timeout

Returns:

  • (String)


1954
1955
1956
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1954

def timeout
  @timeout
end

#when_expressionsArray<Google::Apis::CloudbuildV2::WhenExpression>

Conditions that need to be true for the task to run. Corresponds to the JSON property whenExpressions



1959
1960
1961
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1959

def when_expressions
  @when_expressions
end

#workspacesArray<Google::Apis::CloudbuildV2::WorkspacePipelineTaskBinding>

Workspaces maps workspaces from the pipeline spec to the workspaces declared in the Task. Corresponds to the JSON property workspaces



1965
1966
1967
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1965

def workspaces
  @workspaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 1972

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @retries = args[:retries] if args.key?(:retries)
  @run_after = args[:run_after] if args.key?(:run_after)
  @task_ref = args[:task_ref] if args.key?(:task_ref)
  @task_spec = args[:task_spec] if args.key?(:task_spec)
  @timeout = args[:timeout] if args.key?(:timeout)
  @when_expressions = args[:when_expressions] if args.key?(:when_expressions)
  @workspaces = args[:workspaces] if args.key?(:workspaces)
end