Class: Google::Apis::CloudbuildV2::RunWorkflowCustomOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::RunWorkflowCustomOperationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
Represents the custom metadata of the RunWorkflow long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#pipeline_run_id ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunWorkflowCustomOperationMetadata
constructor
A new instance of RunWorkflowCustomOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunWorkflowCustomOperationMetadata
Returns a new instance of RunWorkflowCustomOperationMetadata.
2330 2331 2332 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
2294 2295 2296 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2294 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
2299 2300 2301 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2299 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
2304 2305 2306 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2304 def end_time @end_time end |
#pipeline_run_id ⇒ String
Output only. ID of the pipeline run created by RunWorkflow.
Corresponds to the JSON property pipelineRunId
2309 2310 2311 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2309 def pipeline_run_id @pipeline_run_id end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
2317 2318 2319 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2317 def requested_cancellation @requested_cancellation end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
2323 2324 2325 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2323 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
2328 2329 2330 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2328 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2335 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @pipeline_run_id = args[:pipeline_run_id] if args.key?(:pipeline_run_id) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |