Class: Google::Apis::CloudbuildV2::SkippedTask

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

SkippedTask is used to describe the Tasks that were skipped due to their When Expressions evaluating to False.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SkippedTask

Returns a new instance of SkippedTask.



2609
2610
2611
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name is the Pipeline Task name Corresponds to the JSON property name

Returns:

  • (String)


2596
2597
2598
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2596

def name
  @name
end

#reasonString

Output only. Reason is the cause of the PipelineTask being skipped. Corresponds to the JSON property reason

Returns:

  • (String)


2601
2602
2603
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2601

def reason
  @reason
end

#when_expressionsArray<Google::Apis::CloudbuildV2::WhenExpression>

WhenExpressions is the list of checks guarding the execution of the PipelineTask Corresponds to the JSON property whenExpressions



2607
2608
2609
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2607

def when_expressions
  @when_expressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2614
2615
2616
2617
2618
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2614

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @reason = args[:reason] if args.key?(:reason)
  @when_expressions = args[:when_expressions] if args.key?(:when_expressions)
end