Class: Google::Apis::CloudbuildV2::StepTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

StepTemplate can be used as the basis for all step containers within the Task, so that the steps inherit settings on the base container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StepTemplate

Returns a new instance of StepTemplate.



2799
2800
2801
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#envArray<Google::Apis::CloudbuildV2::EnvVar>

Optional. List of environment variables to set in the Step. Cannot be updated. Corresponds to the JSON property env



2792
2793
2794
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2792

def env
  @env
end

#volume_mountsArray<Google::Apis::CloudbuildV2::VolumeMount>

Optional. Pod volumes to mount into the container's filesystem. Corresponds to the JSON property volumeMounts



2797
2798
2799
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2797

def volume_mounts
  @volume_mounts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2804
2805
2806
2807
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2804

def update!(**args)
  @env = args[:env] if args.key?(:env)
  @volume_mounts = args[:volume_mounts] if args.key?(:volume_mounts)
end