Class: Google::Apis::CloudbuildV2::TaskSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

TaskSpec contains the Spec to instantiate a TaskRun.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskSpec

Returns a new instance of TaskSpec.



2940
2941
2942
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of the task. Corresponds to the JSON property description

Returns:

  • (String)


2896
2897
2898
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2896

def description
  @description
end

#managed_sidecarsArray<String>

Sidecars that run alongside the Task’s step containers that should be added to this Task. Corresponds to the JSON property managedSidecars

Returns:

  • (Array<String>)


2902
2903
2904
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2902

def managed_sidecars
  @managed_sidecars
end

#paramsArray<Google::Apis::CloudbuildV2::ParamSpec>

List of parameters. Corresponds to the JSON property params



2907
2908
2909
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2907

def params
  @params
end

#resultsArray<Google::Apis::CloudbuildV2::TaskResult>

Values that this Task can output. Corresponds to the JSON property results



2912
2913
2914
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2912

def results
  @results
end

#sidecarsArray<Google::Apis::CloudbuildV2::Sidecar>

Sidecars that run alongside the Task's step containers. Corresponds to the JSON property sidecars



2917
2918
2919
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2917

def sidecars
  @sidecars
end

#step_templateGoogle::Apis::CloudbuildV2::StepTemplate

StepTemplate can be used as the basis for all step containers within the Task, so that the steps inherit settings on the base container. Corresponds to the JSON property stepTemplate



2923
2924
2925
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2923

def step_template
  @step_template
end

#stepsArray<Google::Apis::CloudbuildV2::Step>

Steps of the task. Corresponds to the JSON property steps



2928
2929
2930
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2928

def steps
  @steps
end

#volumesArray<Google::Apis::CloudbuildV2::VolumeSource>

A collection of volumes that are available to mount into steps. Corresponds to the JSON property volumes



2933
2934
2935
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2933

def volumes
  @volumes
end

#workspacesArray<Google::Apis::CloudbuildV2::WorkspaceDeclaration>

The volumes that this Task requires. Corresponds to the JSON property workspaces



2938
2939
2940
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2938

def workspaces
  @workspaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2945

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @managed_sidecars = args[:managed_sidecars] if args.key?(:managed_sidecars)
  @params = args[:params] if args.key?(:params)
  @results = args[:results] if args.key?(:results)
  @sidecars = args[:sidecars] if args.key?(:sidecars)
  @step_template = args[:step_template] if args.key?(:step_template)
  @steps = args[:steps] if args.key?(:steps)
  @volumes = args[:volumes] if args.key?(:volumes)
  @workspaces = args[:workspaces] if args.key?(:workspaces)
end