Class: Google::Apis::CloudbuildV2::VolumeMount

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

Pod volumes to mount into the container's filesystem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VolumeMount

Returns a new instance of VolumeMount.



3094
3095
3096
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mount_pathString

Path within the container at which the volume should be mounted. Must not contain ':'. Corresponds to the JSON property mountPath

Returns:

  • (String)


3067
3068
3069
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3067

def mount_path
  @mount_path
end

#nameString

Name of the volume. Corresponds to the JSON property name

Returns:

  • (String)


3072
3073
3074
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3072

def name
  @name
end

#read_onlyBoolean Also known as: read_only?

Mounted read-only if true, read-write otherwise (false or unspecified). Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


3077
3078
3079
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3077

def read_only
  @read_only
end

#sub_pathString

Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root). Corresponds to the JSON property subPath

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3084

def sub_path
  @sub_path
end

#sub_path_exprString

Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $( VAR_NAME) are expanded using the container's environment. Defaults to "" ( volume's root). Corresponds to the JSON property subPathExpr

Returns:

  • (String)


3092
3093
3094
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3092

def sub_path_expr
  @sub_path_expr
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3099
3100
3101
3102
3103
3104
3105
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3099

def update!(**args)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
  @name = args[:name] if args.key?(:name)
  @read_only = args[:read_only] if args.key?(:read_only)
  @sub_path = args[:sub_path] if args.key?(:sub_path)
  @sub_path_expr = args[:sub_path_expr] if args.key?(:sub_path_expr)
end