Class: Google::Apis::CloudbuildV2::WorkspaceBinding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb

Overview

WorkspaceBinding maps a workspace to a Volume. PipelineRef can be used to refer to a specific instance of a Pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkspaceBinding

Returns a new instance of WorkspaceBinding.



3208
3209
3210
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the workspace. Corresponds to the JSON property name

Returns:

  • (String)


3194
3195
3196
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3194

def name
  @name
end

#secretGoogle::Apis::CloudbuildV2::SecretVolumeSource

Secret Volume Source. Corresponds to the JSON property secret



3199
3200
3201
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3199

def secret
  @secret
end

#sub_pathString

Optional. SubPath is optionally a directory on the volume which should be used for this binding (i.e. the volume will be mounted at this sub directory). + optional Corresponds to the JSON property subPath

Returns:

  • (String)


3206
3207
3208
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3206

def sub_path
  @sub_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3213
3214
3215
3216
3217
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3213

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @secret = args[:secret] if args.key?(:secret)
  @sub_path = args[:sub_path] if args.key?(:sub_path)
end