Class: Google::Apis::CloudbuildV2::Connection
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::Connection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
A connection to a SCM like GitHub, GitHub Enterprise, Bitbucket Data Center, Bitbucket Cloud or GitLab.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#bitbucket_cloud_config ⇒ Google::Apis::CloudbuildV2::BitbucketCloudConfig
Configuration for connections to Bitbucket Cloud.
-
#bitbucket_data_center_config ⇒ Google::Apis::CloudbuildV2::BitbucketDataCenterConfig
Configuration for connections to Bitbucket Data Center.
-
#create_time ⇒ String
Output only.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#github_config ⇒ Google::Apis::CloudbuildV2::GitHubConfig
Configuration for connections to github.com.
-
#github_enterprise_config ⇒ Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig
Configuration for connections to an instance of GitHub Enterprise.
-
#gitlab_config ⇒ Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitLabConfig
Configuration for connections to gitlab.com or an instance of GitLab Enterprise.
-
#installation_state ⇒ Google::Apis::CloudbuildV2::InstallationState
Describes stage and necessary actions to be taken by the user to complete the installation.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Connection
constructor
A new instance of Connection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Connection
Returns a new instance of Connection.
468 469 470 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Allows clients to store small amounts of arbitrary data.
Corresponds to the JSON property annotations
396 397 398 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 396 def annotations @annotations end |
#bitbucket_cloud_config ⇒ Google::Apis::CloudbuildV2::BitbucketCloudConfig
Configuration for connections to Bitbucket Cloud.
Corresponds to the JSON property bitbucketCloudConfig
401 402 403 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 401 def bitbucket_cloud_config @bitbucket_cloud_config end |
#bitbucket_data_center_config ⇒ Google::Apis::CloudbuildV2::BitbucketDataCenterConfig
Configuration for connections to Bitbucket Data Center.
Corresponds to the JSON property bitbucketDataCenterConfig
406 407 408 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 406 def bitbucket_data_center_config @bitbucket_data_center_config end |
#create_time ⇒ String
Output only. Server assigned timestamp for when the connection was created.
Corresponds to the JSON property createTime
411 412 413 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 411 def create_time @create_time end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. If disabled is set to true, functionality is disabled for this
connection. Repository based API methods and webhooks processing for
repositories in this connection will be disabled.
Corresponds to the JSON property disabled
418 419 420 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 418 def disabled @disabled end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
426 427 428 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 426 def etag @etag end |
#github_config ⇒ Google::Apis::CloudbuildV2::GitHubConfig
Configuration for connections to github.com.
Corresponds to the JSON property githubConfig
431 432 433 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 431 def github_config @github_config end |
#github_enterprise_config ⇒ Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitHubEnterpriseConfig
Configuration for connections to an instance of GitHub Enterprise.
Corresponds to the JSON property githubEnterpriseConfig
436 437 438 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 436 def github_enterprise_config @github_enterprise_config end |
#gitlab_config ⇒ Google::Apis::CloudbuildV2::GoogleDevtoolsCloudbuildV2GitLabConfig
Configuration for connections to gitlab.com or an instance of GitLab
Enterprise.
Corresponds to the JSON property gitlabConfig
442 443 444 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 442 def gitlab_config @gitlab_config end |
#installation_state ⇒ Google::Apis::CloudbuildV2::InstallationState
Describes stage and necessary actions to be taken by the user to complete the
installation. Used for GitHub and GitHub Enterprise based connections.
Corresponds to the JSON property installationState
448 449 450 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 448 def installation_state @installation_state end |
#name ⇒ String
Immutable. The resource name of the connection, in the format projects/
project/locations/location/connections/connection_id`.
Corresponds to the JSON propertyname`
454 455 456 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 454 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Set to true when the connection is being set up or updated in the
background.
Corresponds to the JSON property reconciling
460 461 462 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 460 def reconciling @reconciling end |
#update_time ⇒ String
Output only. Server assigned timestamp for when the connection was updated.
Corresponds to the JSON property updateTime
466 467 468 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 466 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 473 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @bitbucket_cloud_config = args[:bitbucket_cloud_config] if args.key?(:bitbucket_cloud_config) @bitbucket_data_center_config = args[:bitbucket_data_center_config] if args.key?(:bitbucket_data_center_config) @create_time = args[:create_time] if args.key?(:create_time) @disabled = args[:disabled] if args.key?(:disabled) @etag = args[:etag] if args.key?(:etag) @github_config = args[:github_config] if args.key?(:github_config) @github_enterprise_config = args[:github_enterprise_config] if args.key?(:github_enterprise_config) @gitlab_config = args[:gitlab_config] if args.key?(:gitlab_config) @installation_state = args[:installation_state] if args.key?(:installation_state) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @update_time = args[:update_time] if args.key?(:update_time) end |