Class: Google::Apis::CloudbuildV2::Repository
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::Repository
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
A repository associated to a parent connection.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#name ⇒ String
Immutable.
-
#remote_uri ⇒ String
Required.
-
#update_time ⇒ String
Output only.
-
#webhook_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Repository
constructor
A new instance of Repository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Repository
Returns a new instance of Repository.
2234 2235 2236 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Allows clients to store small amounts of arbitrary data.
Corresponds to the JSON property annotations
2199 2200 2201 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2199 def annotations @annotations end |
#create_time ⇒ String
Output only. Server assigned timestamp for when the connection was created.
Corresponds to the JSON property createTime
2204 2205 2206 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2204 def create_time @create_time end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
2211 2212 2213 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2211 def etag @etag end |
#name ⇒ String
Immutable. Resource name of the repository, in the format projects/*/
locations/*/connections/*/repositories/*.
Corresponds to the JSON property name
2217 2218 2219 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2217 def name @name end |
#remote_uri ⇒ String
Required. Git Clone HTTPS URI.
Corresponds to the JSON property remoteUri
2222 2223 2224 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2222 def remote_uri @remote_uri end |
#update_time ⇒ String
Output only. Server assigned timestamp for when the connection was updated.
Corresponds to the JSON property updateTime
2227 2228 2229 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2227 def update_time @update_time end |
#webhook_id ⇒ String
Output only. External ID of the webhook created for the repository.
Corresponds to the JSON property webhookId
2232 2233 2234 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2232 def webhook_id @webhook_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2239 2240 2241 2242 2243 2244 2245 2246 2247 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2239 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @remote_uri = args[:remote_uri] if args.key?(:remote_uri) @update_time = args[:update_time] if args.key?(:update_time) @webhook_id = args[:webhook_id] if args.key?(:webhook_id) end |