Class: Google::Apis::CloudbuildV2::TaskRef
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::TaskRef
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
TaskRef can be used to refer to a specific instance of a task. PipelineRef can be used to refer to a specific instance of a Pipeline.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#params ⇒ Array<Google::Apis::CloudbuildV2::Param>
Params contains the parameters used to identify the referenced Tekton resource.
-
#resolver ⇒ String
Resolver is the name of the resolver that should perform resolution of the referenced Tekton resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskRef
constructor
A new instance of TaskRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskRef
Returns a new instance of TaskRef.
2833 2834 2835 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. Name of the task.
Corresponds to the JSON property name
2818 2819 2820 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2818 def name @name end |
#params ⇒ Array<Google::Apis::CloudbuildV2::Param>
Params contains the parameters used to identify the referenced Tekton resource.
Example entries might include "repo" or "path" but the set of params
ultimately depends on the chosen resolver.
Corresponds to the JSON property params
2825 2826 2827 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2825 def params @params end |
#resolver ⇒ String
Resolver is the name of the resolver that should perform resolution of the
referenced Tekton resource.
Corresponds to the JSON property resolver
2831 2832 2833 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2831 def resolver @resolver end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2838 2839 2840 2841 2842 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2838 def update!(**args) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @resolver = args[:resolver] if args.key?(:resolver) end |