Class: Google::Apis::CloudbuildV2::TaskResult
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::TaskResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
TaskResult is used to describe the results of a task.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the result.
-
#name ⇒ String
Name of the result.
-
#properties ⇒ Hash<String,Google::Apis::CloudbuildV2::PropertySpec>
When type is OBJECT, this map holds the names of fields inside that object along with the type of data each field holds.
-
#type ⇒ String
The type of data that the result holds.
-
#value ⇒ Google::Apis::CloudbuildV2::ParamValue
Parameter value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskResult
constructor
A new instance of TaskResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskResult
Returns a new instance of TaskResult.
2875 2876 2877 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of the result.
Corresponds to the JSON property description
2852 2853 2854 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2852 def description @description end |
#name ⇒ String
Name of the result.
Corresponds to the JSON property name
2857 2858 2859 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2857 def name @name end |
#properties ⇒ Hash<String,Google::Apis::CloudbuildV2::PropertySpec>
When type is OBJECT, this map holds the names of fields inside that object
along with the type of data each field holds.
Corresponds to the JSON property properties
2863 2864 2865 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2863 def properties @properties end |
#type ⇒ String
The type of data that the result holds.
Corresponds to the JSON property type
2868 2869 2870 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2868 def type @type end |
#value ⇒ Google::Apis::CloudbuildV2::ParamValue
Parameter value.
Corresponds to the JSON property value
2873 2874 2875 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2873 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 2880 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |