Class: Google::Apis::CloudbuildV2::TimeoutFields
- Inherits:
-
Object
- Object
- Google::Apis::CloudbuildV2::TimeoutFields
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudbuild_v2/classes.rb,
lib/google/apis/cloudbuild_v2/representations.rb,
lib/google/apis/cloudbuild_v2/representations.rb
Overview
TimeoutFields allows granular specification of pipeline, task, and finally timeouts
Instance Attribute Summary collapse
-
#finally ⇒ String
Finally sets the maximum allowed duration of this pipeline's finally Corresponds to the JSON property
finally. -
#pipeline ⇒ String
Pipeline sets the maximum allowed duration for execution of the entire pipeline.
-
#tasks ⇒ String
Tasks sets the maximum allowed duration of this pipeline's tasks Corresponds to the JSON property
tasks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeoutFields
constructor
A new instance of TimeoutFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeoutFields
Returns a new instance of TimeoutFields.
3020 3021 3022 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finally ⇒ String
Finally sets the maximum allowed duration of this pipeline's finally
Corresponds to the JSON property finally
3006 3007 3008 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3006 def finally @finally end |
#pipeline ⇒ String
Pipeline sets the maximum allowed duration for execution of the entire
pipeline. The sum of individual timeouts for tasks and finally must not exceed
this value.
Corresponds to the JSON property pipeline
3013 3014 3015 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3013 def pipeline @pipeline end |
#tasks ⇒ String
Tasks sets the maximum allowed duration of this pipeline's tasks
Corresponds to the JSON property tasks
3018 3019 3020 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3018 def tasks @tasks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3025 3026 3027 3028 3029 |
# File 'lib/google/apis/cloudbuild_v2/classes.rb', line 3025 def update!(**args) @finally = args[:finally] if args.key?(:finally) @pipeline = args[:pipeline] if args.key?(:pipeline) @tasks = args[:tasks] if args.key?(:tasks) end |